import scrapy, re

# from datetime import datetime, date, timedelta
# from scrapy.spidermiddlewares.httperror import HttpError

"""
Esta version descarga todas las noticias contenidas en la pagina, sin necesidad
de una fecha especifica.
USO:

scrapy crawl noticias -t json --nolog -o noticias.json
"""

TAG_RE = re.compile(r'<[^>]+>')


def remove_tags(text):
    return TAG_RE.sub('', text)


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        section_list = ['merida', 'yucatan', 'mexico', 'internacional', 'deportes', 'mexico/quintana-roo',
                        'espectaculos', 'imagen', 'economia', 'tecnologia', 'salud', 'editorial', 'multimedia']
        # section_list = ['yucatan', 'salud', 'editorial', 'imagen',
        #                 'merida', 'merida/clima', 'merida/gobierno', 'merida/policia', 'merida/politica',
        #                 'mexico', 'mexico/quintana-roo', 'mexico/cdmx', 'mexico/economia', 'mexico/campeche',
        #                 'internacional', 'internacional/asia', 'internacional/europa', 'internacional/africa',
        #                 'internacional/america', 'internacional/oceania',
        #                 'deportes', 'deportes/futbol', 'deportes/nfl',
        #                 'espectaculos', 'espectaculos/cine', 'espectaculos/farandula', 'espectaculos/musica',
        #                 'espectaculos/tv-y-series',
        #                 'tecnologia', 'tecnologia/redes-sociales', 'tecnologia/innovaciones',
        #                 'multimedia', 'multimedia/fotos', 'multimedia/videos']

        self.globalLinkSet = set()
        self.baseURL = 'http://www.yucatan.com.mx/seccion/'
        self.parsing_month = {'enero': 1, 'febrero': 2, 'marzo': 3, 'abril': 4, 'mayo': 5, 'junio': 6, 'julio': 7,
                              'agosto': 8, 'septiembre': 9, 'octubre': 10, 'noviembre': 11, 'diciembre': 12}

        for s in section_list:
            yield scrapy.Request(url=self.baseURL + s, callback=self.parse)


    def parse(self, response):
        pathList = ['//*[@class="g1-column"]/div/div/article',
                    '//*[@class="g1-collection g1-collection-columns-2"]/div/ul/li/article']

        for path in pathList:
            for entry in response.xpath(path):
                link = entry.css('h3').css('a::attr(href)').extract_first()

                if not link in self.globalLinkSet:
                    self.globalLinkSet.add(link)
                    item = NoticiasItem()

                    item['topic'] = remove_tags(response.xpath('//h2[@class="g1-delta g1-delta-2nd resaltartitulo"]').extract_first())
                    request = scrapy.Request(url=link, callback=self.parse_item)

                    request.meta['item'] = item
                    yield request


    def parse_item(self, response):
        item = response.meta['item']
        text = ''

        item['date'] = response.xpath('//time[@class="entry-date"]/@datetime').extract_first() + "-06:00"
        item['title'] = remove_tags(response.xpath('//h1[@class="g1-mega g1-mega-1st entry-title"]').extract_first())

        for p in response.xpath('//*[@itemprop="articleBody"]/p').extract():
            text += remove_tags(p) + "\n"

        item['text'] = text
        item['url'] = response.url
        # print item['title']
        yield item

