import scrapy, re

"""
MEDIO:
Campeche Hoy, Campeche
USO:
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2018 -a month=1 -a day=17
"""

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

TRASH_RE = re.compile(r'<.*?>.*</.*?>\s?')


class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
    name = "noticias"

    def start_requests(self):
        year = getattr(self, "year", None)
        month = getattr(self, "month", None)
        day = getattr(self, "day", None)

        self.baseURL = "http://campechehoy.mx/" + year + "/" + month + "/" + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)


    def parse(self, response):
        yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
        pagination = response.xpath('//*[@class="page-nav td-pb-padding-side"]/a/@href').extract()
        if pagination is not None and len(pagination) > 0:
            pages = pagination[-2].rstrip("/")
            pages = int(pages[pages.rfind("/")+1:])

            for page in range(1, pages):
                yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)


    def parse_page(self, response):
        for link in response.xpath('//*[@class="td-pb-span8 td-main-content"]').css('h3').css('a::attr(href)').extract():
            yield scrapy.Request(url=link, callback=self.parse_item)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        "La fecha obtenida ya incluye formato y zona horaria"
        item['date'] = response.xpath('//span[@class="td-post-date"]/time/@datetime').extract_first()
        item['title'] = remove_tags(response.xpath('//header/h1[@class="entry-title"]').extract_first())
        try:
            topic = response.xpath('//*[@class="td-post-source-tags td-pb-padding-side"]/ul/li/a/text()').extract()[1]
        except:
            topic = response.xpath('//*[@class="td-post-source-tags td-pb-padding-side"]/ul/li/a/text()').extract_first()
        item['topic'] = topic

        for p in response.xpath('//*[@class="td-post-content td-pb-padding-side"]/p').extract():
            p = remove_tags(p)
            p = p.replace("&lt;", "<")
            p = p.replace("&gt;", ">")
            text += remove_tags(p) + "\n"
        item['text'] = text

        item['url'] = response.url

        yield item
