import scrapy, re

'''
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=3 -a day=22
'''

TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
    return TAG_RE.sub('', text)

class NoticiasItem(scrapy.Item):
    title = scrapy.Field()
    text = scrapy.Field()
    date = scrapy.Field()
    location = scrapy.Field()
    author = scrapy.Field()
    topic = scrapy.Field()
    url = scrapy.Field()

# class QuotesSpider(scrapy.Spider):
# 	name = "noticias"
# 	def start_requests(self):
# 		year = getattr(self, 'year', None)
# 		month = getattr(self, 'month', None)
# 		day = getattr(self, 'day', None)
# 		self.baseURL='http://laverdadnoticias.com/'+year+'/'+month+'/'+day
# 		urls = [
# 			self.baseURL,
# 								]
# 		for url in urls:
# 			yield scrapy.Request(url=url, callback=self.parse)

# 	def parse(self, response):
# 		pagination = response.css("div.pagination_div").css("a::attr(href)").extract()
# 		if ( len(pagination) > 0 ):
# 			pagination = pagination[-2].strip('/')
# 			pages = int(pagination[pagination.rfind('/')+1:])
# 			for page in range(0,pages):
# 				if ( page == 0 ):
# 					yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
# 				else:
# 					yield scrapy.Request(url=self.baseURL+"/page/"+str(page+1), callback=self.parse_page)
# 		else:
# 			yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

# 	def parse_page(self, response):
# 		item = NoticiasItem()
# 		for post in response.css('div.col-md-12').css('div.cp-post-content'):
# 			item['topic'] = post.css('ul.cp-post-tools').css('li').css('a::attr(title)').extract()
# 			item['author'] = post.css('ul.cp-post-tools').xpath('./li[2]/text()').extract_first()
# 			request = scrapy.Request(url=post.xpath('./h3/a/@href').extract_first(), callback=self.parse_item)
# 			request.meta['item'] = item
# 			yield request

# 	def parse_item(self, response):
# 		item = response.meta['item']
# 		text = ''
# 		item['title'] = response.css("div.cp-post-content").css("h1").css("a::text").extract_first()
# 		item['date'] = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
# 		for paragraph in response.css("div.cp-post-content").css("p").extract():
# 			text += remove_tags(paragraph) + '\n'
# 		item['text'] = text
# 		item['url'] = response.url
# 		# print item['title']
# 		yield item

class QuotesSpider(scrapy.Spider):
    # handle_httpstatus_list = [404]
    name = "noticias"

    def start_requests(self):
        year = getattr(self, 'year', None)
        month = getattr(self, 'month', None)
        day = getattr(self, 'day', None)
        self.baseURL = 'http://laverdadnoticias.com/' + year + '/' + month + '/' + day

        yield scrapy.Request(url=self.baseURL, callback=self.parse)

        # while not self.stop:
        # # for page in range(0, 50):
        # 	if page == 0:
        # 		yield scrapy.Request(url=self.baseURL, callback=self.parse, errback=self.errback_http)
        # 	elif page > 0:
        # 		yield scrapy.Request(url=self.baseURL+'/page/'+str(page), callback=self.parse, errback=self.errback_http)

        # 	page += 1


    def parse(self, response):
        # if response.status == 404:
        # 	print('**********hey, 404! TRUE!!!')
        # 	self.stop = True
        # else:
        linkList = response.xpath('//*[@class="two_third post_header"]/h5/a/@href').extract()
        linkList.extend(response.xpath('//*[@class="post_header_title two_third last"]/h5/a/@href').extract())
        linkList.extend(response.xpath('//*[@class="post_header_title one"]/h5/a/@href').extract())

        for link in linkList:
            yield scrapy.Request(url=link, callback=self.parse_item)

        nextPage = response.xpath('//*[@class="pagination"]/a/@href').extract()[-1]
        yield scrapy.Request(url=nextPage, callback=self.parse)


    def parse_item(self, response):
        item = NoticiasItem()
        text = ''

        d = response.xpath('//meta[@property="article:published_time"]/@content').extract_first()
        if d is None or d == '':
            d = response.xpath('//meta[@property="DC.date.issued"]/@content').extract_first()
        ## '-06:00' corresponde al UTC-6, zona horaria de yucatan (centro de mexico)
        if d[-6:] != '-06:00':
            d = d[:-6] + '-06:00'
        item['date'] = d

        item['title'] = response.xpath('//*[@class="page_title_inner"]/h1/text()').extract_first()
        item['topic'] = response.xpath('//*[@class="post_info_cat"]/a/text()').extract_first()

        paragraph = response.xpath('//*[@class="post_content_wrapper"]/p').extract()
        paragraph.extend(response.xpath('//*[@title="Page 1"]/div/p').extract())
        paragraph.extend(response.xpath('//*[@class="text_exposed_root text_exposed"]/p').extract())
        for p in paragraph:
            text += remove_tags(p) + '\n'

        item['text'] = text
        item['url'] = response.url

        # print item['title']
        yield item