import scrapy, re
from datetime import datetime, timedelta, tzinfo

'''
scrapy crawl noticias -t json --nolog -o noticias.json -a year=2017 -a month=9 -a day=22
'''


TAG_RE = re.compile(r'<[^>]+>')
def remove_tags(text):
	return TAG_RE.sub('', text)


class UTC(tzinfo):
	"""clase para el 'time zone' (zona horaria)"""

	def utcoffset(self, dt):
		# zona horaria para hidalgo (centro de mexico): utc-6
		return timedelta(hours=-6)

	def tzname(self, dt):
		# nombre de la zona horaria
		return 'UTC-6'


class NoticiasItem(scrapy.Item):
	title = scrapy.Field()
	text = scrapy.Field()
	date = scrapy.Field()
	location = scrapy.Field()
	author = scrapy.Field()
	topic = scrapy.Field()
	url = scrapy.Field()


class QuotesSpider(scrapy.Spider):
	name = "noticias"
	
	def start_requests(self):
		self.tz = UTC()
		year = getattr(self, 'year', None)
		month = getattr(self, 'month', None)
		day = getattr(self, 'day', None)
		self.date_parser = {'enero': 1,      'febrero': 2,  'marzo': 3,      'abril': 4,
							'mayo': 5,       'junio': 6,    'julio': 7,      'agosto': 8,
							'septiembre': 9, 'octubre': 10, 'noviembre': 11, 'diciembre': 12}
		
		self.baseURL='http://www.unomasuno.com.mx/'+year+'/'+month+'/'+day
		
		yield scrapy.Request(url=self.baseURL, callback=self.parse)


	def parse(self, response):
		pagination = response.xpath('//*[@class="pagination"]/a[@class="last"]/@href').extract_first()

		if pagination is None:
			pagination = response.xpath('//*[@class="pagination"]/a/@href').extract()
		
			if len(pagination) > 0:
				pagination = pagination[-1].strip('/')
				pages = int(pagination[pagination.rfind('/')+1:])
				
				for page in range(0,pages):
					if page == 0:
						yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
					else:
						yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)
			
			else:
				yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)

		else:
			pagination = pagination.strip('/')
			pages = int(pagination[pagination.rfind('/')+1:])

			for page in range(0,pages):
				if page == 0:
					yield scrapy.Request(url=response.url, callback=self.parse_page, dont_filter=True)
				else:
					yield scrapy.Request(url=self.baseURL+'/page/'+str(page+1), callback=self.parse_page)


	def parse_page(self, response):
		for link in response.xpath('//h2[@class="post-box-title"]/a/@href').extract():
			yield scrapy.Request(url=link, callback=self.parse_item)


	def parse_item(self, response):
		item = NoticiasItem()
		text = ''
		
		d = response.xpath('//p[@class="post-meta"]/span/text()').extract_first()
		d = d.replace(',','').split(' ')
		item['date'] = datetime(int(d[2]), self.date_parser[d[1].lower()], int(d[0]), tzinfo=self.tz).isoformat('T')

		item['topic'] = response.xpath('//span[@typeof="v:Breadcrumb"]/a/text()').extract()[1]
		item['title'] = response.xpath('//*[@class="post-inner"]/h1/span/text()').extract_first()
		
		for p in response.xpath('//*[@class="entry"]/p').extract():
			text += remove_tags(p) + '\n'
		
		item['text'] = text
		item['url'] = response.url
		
		# print item['title']
		yield item

